# SWAN MkDocs theme

Theme for the [SWAN](https://cern.ch/swan) help and gallery [MkDocs](https://www.mkdocs.org/) webpages, based on [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/).

## How to use

Install the package:
```
pip install mkdocs-swan
```

And add it to `mkdocs.yml`:
```yml
theme:
  name: 'swan'
```